@@ -2,21 +2,22 @@
 
 set -ex
 
-TESTDIR="$(dirname "${0}")"
-PLAN_DIRECTORY="$(dirname "${TESTDIR}")"
+export SCRIPTS_DIRECTORY="$(dirname "${0}")"
+export PLAN_DIRECTORY="$(dirname "${SCRIPTS_DIRECTORY}")"
+export BIOME_DIRECTORY="$(dirname "${PLAN_DIRECTORY}")"
+export ROOT_DIRECTORY="$(dirname "${BIOME_DIRECTORY}")"
 
-bio pkg install --binlink themelio/bats
-bio pkg install --binlink core/curl
-bio pkg install --binlink core/nmap
 
-rm -rf ${PLAN_DIRECTORY}/hooks
+export THEMELIO_NODE_VERSION=$(cat "${ROOT_DIRECTORY}/Cargo.toml" | tomlq .package.version | tr -d '"')
 
 if [ "${NETWORK_TO_BUILD}" == "mainnet" ]; then
-  cp "${PLAN_DIRECTORY}/plan-debug-mainnet.sh" "${PLAN_DIRECTORY}/plan.sh"
+  echo "Building for mainnet."
+  envsubst '${THEMELIO_NODE_VERSION}' < "${PLAN_DIRECTORY}/plan-debug-mainnet.sh" > "${PLAN_DIRECTORY}/plan.sh"
   cp -r "${PLAN_DIRECTORY}/hooks-mainnet" "${PLAN_DIRECTORY}/hooks"
 
 elif [ "${NETWORK_TO_BUILD}" == "testnet" ]; then
-  cp "${PLAN_DIRECTORY}/plan-debug-testnet.sh" "${PLAN_DIRECTORY}/plan.sh"
+  echo "Building for testnet."
+  envsubst '${THEMELIO_NODE_VERSION}' < "${PLAN_DIRECTORY}/plan-debug-testnet.sh" > "${PLAN_DIRECTORY}/plan.sh"
   cp -r "${PLAN_DIRECTORY}/hooks-testnet" "${PLAN_DIRECTORY}/hooks"
 
 else
@@ -24,6 +25,10 @@ else
   exit 1
 fi
 
+bio pkg install --binlink themelio/bats
+bio pkg install --binlink core/curl
+bio pkg install --binlink core/nmap
+
 pushd "${PLAN_DIRECTORY}"
 
 source "plan.sh"
